@@ -1,5 +1,5 @@
 /*
-Copyright  1998. The Regents of the University of California (Regents). 
+Copyright  1998. The Regents of the University of California (Regents).
 All Rights Reserved.
 
 Written by Matt Wright, The Center for New Music and Audio Technologies,
@@ -22,14 +22,20 @@ PURPOSE. THE SOFTWARE AND ACCOMPANYING DOCUMENTATION, IF ANY, PROVIDED
 HEREUNDER IS PROVIDED "AS IS". REGENTS HAS NO OBLIGATION TO PROVIDE
 MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 
-The OpenSound Control WWW page is 
+The OpenSound Control WWW page is
     http://www.cnmat.berkeley.edu/OpenSoundControl
 */
 
+#ifndef IS_MINGW
 #include <netinet/in.h>
+#else
+#include <winsock2.h>
+#include <ws2tcpip.h>
+#endif
 
 struct NetworkReturnAddressStruct {
-    struct sockaddr_in  cl_addr;
-    socklen_t clilen;
-    int sockfd;
+  struct sockaddr_in  cl_addr;
+  socklen_t clilen;
+  int sockfd;
 };
+
