@@ -42,7 +42,7 @@
 
 */
 
-/* (C) Gabriel "Salsaman" Finch, 2005 - 2011 */
+/* (C) Gabriel "Salsaman" Finch, 2005 - 2012 */
 
 #ifndef __WEED_COMPAT_H__
 #define __WEED_COMPAT_H__
@@ -52,12 +52,157 @@ extern "C"
 {
 #endif /* __cplusplus */
 
-#ifdef HAVE_AVCODEC
 
-  // compatibility with libavcodec
+#ifdef NEED_FOURCC_COMPAT
+
+#ifndef __WEED_PALETTES_H__
+#include <weed/weed-palettes.h>
+#endif
+
+int fourccp_to_weedp(unsigned int fourcc, int bpp, int *interlaced, int *sampling,
+                     int *sspace, int *clamping) {
+  // inputs are fourcc and bpp
+  // returns int weed_palette
+
+  // optionally sets interlaced (0 = none, 1 = interlaced), sampling, subspace and clamping
+
+
+
+  // TODO - this is probably wrong for some formats and needs testing/verifying with various devices
+  // fourcc colorcodes are a nasty mess, and should be avoided whenever possible
+
+  // data from http://www.fourcc.org
+
+  if (clamping!=NULL) *clamping=WEED_YUV_CLAMPING_CLAMPED;
+  if (interlaced!=NULL) *interlaced=0;
+  if (sspace!=NULL) *sspace=WEED_YUV_SUBSPACE_YCBCR;
+  if (sampling!=NULL) *sampling=WEED_YUV_SAMPLING_DEFAULT;
+
+  switch (fourcc) {
+
+  // RGB formats
+
+  case 0x32524742: // BGR3
+  case 0x33524742: // BGR3 - tested and OK
+  case 0x34524742: // BGR4
+    if (bpp==24) return WEED_PALETTE_BGR24;
+    if (bpp==32) return WEED_PALETTE_BGRA32;
+    break;
+
+  case 0x00000000: // BI_RGB - RGB or BGR ???
+  case 0x32776172: // raw2 - RGB or BGR ???
+
+  case 0x32424752: // RGB2
+  case 0x33424752: // RGB3
+  case 0x34424752: // RGB4
+    if (bpp==24) return WEED_PALETTE_RGB24;
+    if (bpp==32) return WEED_PALETTE_RGBA32;
+    break;
+  case 0x41424752: // RGBA
+    if (bpp==32) return WEED_PALETTE_RGBA32;
+    break;
+
+
+  // YUV packed formats
+
+  case 0x56595549: // IUYV
+    if (interlaced!=NULL) *interlaced=1;
+    return WEED_PALETTE_UYVY;
+  case 0x31555949: // IYU1
+  case 0x31313459: // Y411
+    return WEED_PALETTE_YUV411;
+  case 0x32555949: // IYU2
+    return WEED_PALETTE_YUV888;
+  case 0x43594448: // HDYC
+    if (sspace!=NULL) *sspace=WEED_YUV_SUBSPACE_BT709;
+    return WEED_PALETTE_UYVY;
+  case 0x564E5955: // UYNV
+  case 0x59565955: // UYVY
+  case 0x32323459: // Y422
+  case 0x76757963: // cyuv - ???
+    return WEED_PALETTE_UYVY;
+  case 0x32595559: // YUY2
+  case 0x56595559: // YUYV - tested and OK
+  case 0x564E5559: // YUNV
+  case 0x31313259: // Y211 - ???
+    return WEED_PALETTE_YUYV;
+  case 0x59455247: // grey
+    if (clamping!=NULL) *clamping=WEED_YUV_CLAMPING_UNCLAMPED;
+  case 0x30303859: // Y800
+  case 0x20203859: // Y8
+    return WEED_PALETTE_A8;
+
+
+  // YUV planar formats
+  case 0x41565559: // YUVA
+    return WEED_PALETTE_YUVA4444P;
+    break;
+  case 0x34343449: // I444
+    return WEED_PALETTE_YUV444P;
+    break;
+  case 0x50323234: // 422P ??
+    return WEED_PALETTE_YUV422P;
+    break;
+  case 0x32315659: // YV12
+    return WEED_PALETTE_YVU420P;
+  case 0x30323449: // I420
+  case 0x56555949: // IYUV
+  case 0x32315559: // YU12 ??
+    return WEED_PALETTE_YUV420P;
+
+  case 0x3032344a: // J420
+    if (clamping!=NULL) *clamping=WEED_YUV_CLAMPING_UNCLAMPED;
+    return WEED_PALETTE_YUV420P;
+  case 0x3232344a: // J422
+    if (clamping!=NULL) *clamping=WEED_YUV_CLAMPING_UNCLAMPED;
+    return WEED_PALETTE_YUV422P;
+  case 0x3434344a: // J444
+    if (clamping!=NULL) *clamping=WEED_YUV_CLAMPING_UNCLAMPED;
+    return WEED_PALETTE_YUV444P;
+
+
+  // known formats we cannot use
+  case 0x50424752: // RGBP - palettised RGB
+  case 0x4f424752: // RGB0 - 15 or 16 bit RGB
+  case 0x51424752: // RGBQ - 15 or 16 bit RGB
+  case 0x52424752: // RGBR - ???
+
+  case 0x3231564e: // NV12 - planar Y, packed UV
+  case 0x30313276: // v210 - 10 bit 422, packed
+
+  case 0x39565559: // YUV9 - 410 planar palette
+  case 0x30313449: // I410 - 410 planar palette
+
+  case 0x31313449: // I411 - 411 planar palette
+  case 0x30343449: // I440 - 440 planar palette
+  case 0x30343450: // J440 - 440 planar palette unclamped
+
+  // no match
+  default:
+    return WEED_PALETTE_END;
+  }
+  return WEED_PALETTE_END;
+}
+
+
+
+
+#endif
+
+
+
+
+
+
+
+
+#ifdef HAVE_AVCODEC
+#ifdef HAVE_AVUTIL
+
+// compatibility with libavcodec
 
 #include <libavcodec/avcodec.h>
-
+#include <libavutil/pixfmt.h>
 
 typedef struct AVCodecTag {
   int id;
@@ -66,6 +211,168 @@ typedef struct AVCodecTag {
 
 #ifndef MKTAG
 #define MKTAG(a,b,c,d) ((a) | ((b) << 8) | ((c) << 16) | ((d) << 24))
+#endif
+
+
+#if (LIBAVCODEC_VERSION_MAJOR > 54)
+#define CodecID AVCodecID
+
+#define CODEC_ID_NONE AV_CODEC_ID_NONE
+#define CODEC_ID_H264 AV_CODEC_ID_H264
+#define CODEC_ID_H263 AV_CODEC_ID_H263
+#define CODEC_ID_H263P AV_CODEC_ID_H263P
+#define CODEC_ID_H263I AV_CODEC_ID_H263I
+#define CODEC_ID_H261 AV_CODEC_ID_H261
+#define CODEC_ID_MPEG4 AV_CODEC_ID_MPEG4
+#define CODEC_ID_MSMPEG4V3 AV_CODEC_ID_MSMPEG4V3
+#define CODEC_ID_MSMPEG4V2 AV_CODEC_ID_MSMPEG4V2
+#define CODEC_ID_MSMPEG4V1 AV_CODEC_ID_MSMPEG4V1
+#define CODEC_ID_WMV1 AV_CODEC_ID_WMV1
+#define CODEC_ID_WMV2 AV_CODEC_ID_WMV2
+#define CODEC_ID_DVVIDEO AV_CODEC_ID_DVVIDEO
+#define CODEC_ID_MPEG1VIDEO AV_CODEC_ID_MPEG1VIDEO
+#define CODEC_ID_MPEG2VIDEO AV_CODEC_ID_MPEG2VIDEO
+#define CODEC_ID_MJPEG AV_CODEC_ID_MJPEG
+#define CODEC_ID_LJPEG AV_CODEC_ID_LJPEG
+#define CODEC_ID_JPEGLS AV_CODEC_ID_JPEGLS
+#define CODEC_ID_HUFFYUV AV_CODEC_ID_HUFFYUV
+#define CODEC_ID_FFVHUFF AV_CODEC_ID_FFVHUFF
+#define CODEC_ID_CYUV AV_CODEC_ID_CYUV
+#define CODEC_ID_RAWVIDEO AV_CODEC_ID_RAWVIDEO
+#define CODEC_ID_INDEO2 AV_CODEC_ID_INDEO2
+#define CODEC_ID_INDEO3 AV_CODEC_ID_INDEO3
+#define CODEC_ID_INDEO4 AV_CODEC_ID_INDEO4
+#define CODEC_ID_INDEO5 AV_CODEC_ID_INDEO5
+#define CODEC_ID_VP3 AV_CODEC_ID_VP3
+#define CODEC_ID_VP5 AV_CODEC_ID_VP5
+#define CODEC_ID_VP6 AV_CODEC_ID_VP6
+#define CODEC_ID_VP6F AV_CODEC_ID_VP6F
+#define CODEC_ID_VP6A AV_CODEC_ID_VP6A
+#define CODEC_ID_ASV1 AV_CODEC_ID_ASV1
+#define CODEC_ID_ASV2 AV_CODEC_ID_ASV2
+#define CODEC_ID_VCR1 AV_CODEC_ID_VCR1
+#define CODEC_ID_FFV1 AV_CODEC_ID_FFV1
+#define CODEC_ID_XAN_WC4 AV_CODEC_ID_XAN_WC4
+#define CODEC_ID_MIMIC AV_CODEC_ID_MIMIC
+#define CODEC_ID_MSRLE AV_CODEC_ID_MSRLE
+#define CODEC_ID_MSVIDEO1 AV_CODEC_ID_MSVIDEO1
+#define CODEC_ID_CINEPAK AV_CODEC_ID_CINEPAK
+#define CODEC_ID_TRUEMOTION1 AV_CODEC_ID_TRUEMOTION1
+#define CODEC_ID_TRUEMOTION2 AV_CODEC_ID_TRUEMOTION2
+#define CODEC_ID_MSZH AV_CODEC_ID_MSZH
+#define CODEC_ID_ZLIB AV_CODEC_ID_ZLIB
+
+#if FF_API_SNOW
+#define CODEC_ID_SNOW AV_CODEC_ID_SNOW
+#endif
+
+#define CODEC_ID_4XM AV_CODEC_ID_4XM
+#define CODEC_ID_FLV1 AV_CODEC_ID_FLV1
+#define CODEC_ID_FLASHSV AV_CODEC_ID_FLASHSV
+#define CODEC_ID_SVQ1 AV_CODEC_ID_SVQ1
+#define CODEC_ID_TSCC AV_CODEC_ID_TSCC
+#define CODEC_ID_ULTI AV_CODEC_ID_ULTI
+#define CODEC_ID_VIXL AV_CODEC_ID_VIXL
+#define CODEC_ID_QPEG AV_CODEC_ID_QPEG
+#define CODEC_ID_WMV3 AV_CODEC_ID_WMV3
+#define CODEC_ID_VC1 AV_CODEC_ID_VC1
+#define CODEC_ID_LOCO AV_CODEC_ID_LOCO
+#define CODEC_ID_WNV1 AV_CODEC_ID_WNV1
+#define CODEC_ID_AASC AV_CODEC_ID_AASC
+#define CODEC_ID_FRAPS AV_CODEC_ID_FRAPS
+#define CODEC_ID_THEORA AV_CODEC_ID_THEORA
+#define CODEC_ID_CSCD AV_CODEC_ID_CSCD
+#define CODEC_ID_ZMBV AV_CODEC_ID_ZMBV
+#define CODEC_ID_KMVC AV_CODEC_ID_KMVC
+#define CODEC_ID_CAVS AV_CODEC_ID_CAVS
+#define CODEC_ID_JPEG2000 AV_CODEC_ID_JPEG2000
+#define CODEC_ID_VMNC AV_CODEC_ID_VMNC
+#define CODEC_ID_TARGA AV_CODEC_ID_TARGA
+#define CODEC_ID_PNG AV_CODEC_ID_PNG
+#define CODEC_ID_GIF AV_CODEC_ID_GIF
+#define CODEC_ID_TIFF AV_CODEC_ID_TIFF
+#define CODEC_ID_CLJR AV_CODEC_ID_CLJR
+#define CODEC_ID_DIRAC AV_CODEC_ID_DIRAC
+#define CODEC_ID_RPZA AV_CODEC_ID_RPZA
+#define CODEC_ID_SP5X AV_CODEC_ID_SP5X
+
+#define CODEC_ID_FLASHSV2 AV_CODEC_ID_FLASHSV2
+#define CODEC_ID_TEXT AV_CODEC_ID_TEXT
+#define CODEC_ID_SSA AV_CODEC_ID_SSA
+#define CODEC_ID_SRT AV_CODEC_ID_SRT
+#define CODEC_ID_VP8 AV_CODEC_ID_VP8
+#define CODEC_ID_RV10 AV_CODEC_ID_RV10
+#define CODEC_ID_RV20 AV_CODEC_ID_RV20
+#define CODEC_ID_RV30 AV_CODEC_ID_RV30
+#define CODEC_ID_RV40 AV_CODEC_ID_RV40
+#define CODEC_ID_MP3 AV_CODEC_ID_MP3
+#define CODEC_ID_MP2 AV_CODEC_ID_MP2
+#define CODEC_ID_AAC AV_CODEC_ID_AAC
+#define CODEC_ID_PCM_BLURAY AV_CODEC_ID_PCM_BLURAY
+#define CODEC_ID_AC3 AV_CODEC_ID_AC3
+#define CODEC_ID_VORBIS AV_CODEC_ID_VORBIS
+#define CODEC_ID_EAC3 AV_CODEC_ID_EAC3
+#define CODEC_ID_DTS AV_CODEC_ID_DTS
+#define CODEC_ID_TRUEHD AV_CODEC_ID_TRUEHD
+#define CODEC_ID_S302M AV_CODEC_ID_S302M
+#define CODEC_ID_DVB_TELETEXT AV_CODEC_ID_DVB_TELETEXT
+#define CODEC_ID_DVB_SUBTITLE AV_CODEC_ID_DVB_SUBTITLE
+#define CODEC_ID_DVD_SUBTITLE AV_CODEC_ID_DVD_SUBTITLE
+
+#define CODEC_ID_MOV_TEXT AV_CODEC_ID_MOV_TEXT
+#define CODEC_ID_MP4ALS AV_CODEC_ID_MP4ALS
+#define CODEC_ID_QCELP AV_CODEC_ID_QCELP
+#define CODEC_ID_MPEG4SYSTEMS AV_CODEC_ID_MPEG4SYSTEMS
+
+#define CODEC_ID_MPEG2TS AV_CODEC_ID_MPEG2TS
+#define CODEC_ID_AAC_LATM AV_CODEC_ID_AAC_LATM
+#define CODEC_ID_HDMV_PGS_SUBTITLE AV_CODEC_ID_HDMV_PGS_SUBTITLE
+
+#define CODEC_ID_FLAC AV_CODEC_ID_FLAC
+#define CODEC_ID_MLP AV_CODEC_ID_MLP
+
+#define CODEC_ID_PCM_F32LE AV_CODEC_ID_PCM_F32LE
+#define CODEC_ID_PCM_F64LE AV_CODEC_ID_PCM_F64LE
+
+#define CODEC_ID_PCM_S16BE AV_CODEC_ID_PCM_S16BE
+#define CODEC_ID_PCM_S24BE AV_CODEC_ID_PCM_S24BE
+#define CODEC_ID_PCM_S32BE AV_CODEC_ID_PCM_S32BE
+
+#define CODEC_ID_PCM_S16LE AV_CODEC_ID_PCM_S16LE
+#define CODEC_ID_PCM_S24LE AV_CODEC_ID_PCM_S24LE
+#define CODEC_ID_PCM_S32LE AV_CODEC_ID_PCM_S32LE
+
+#define CODEC_ID_PCM_U8 AV_CODEC_ID_PCM_U8
+
+#define CODEC_ID_QDM2 AV_CODEC_ID_QDM2
+#define CODEC_ID_RA_144 AV_CODEC_ID_RA_144
+#define CODEC_ID_RA_288 AV_CODEC_ID_RA_288
+#define CODEC_ID_ATRAC3 AV_CODEC_ID_ATRAC3
+#define CODEC_ID_COOK AV_CODEC_ID_COOK
+#define CODEC_ID_SIPR AV_CODEC_ID_SIPR
+#define CODEC_ID_TTA AV_CODEC_ID_TTA
+#define CODEC_ID_WAVPACK AV_CODEC_ID_WAVPACK
+
+#define CODEC_ID_TTF AV_CODEC_ID_TTF
+
+// from mkv_decoder.h
+#define CODEC_ID_R10K AV_CODEC_ID_R10K
+#define CODEC_ID_R210 AV_CODEC_ID_R210
+#define CODEC_ID_V210 AV_CODEC_ID_V210
+#define CODEC_ID_MJPEGB AV_CODEC_ID_MJPEGB
+#define CODEC_ID_SVQ3 AV_CODEC_ID_SVQ3
+#define CODEC_ID_8BPS AV_CODEC_ID_8BPS
+#define CODEC_ID_SMC AV_CODEC_ID_SMC
+#define CODEC_ID_QTRLE AV_CODEC_ID_QTRLE
+#define CODEC_ID_QDRAW AV_CODEC_ID_QDRAW
+#define CODEC_ID_DNXHD AV_CODEC_ID_DNXHD
+#define CODEC_ID_SGI AV_CODEC_ID_SGI
+#define CODEC_ID_DPX AV_CODEC_ID_DPX
+#define CODEC_ID_PRORES AV_CODEC_ID_PRORES
+
+
+
+
 #endif
 
 const AVCodecTag codec_bmp_tags[] = {
@@ -92,7 +399,7 @@ const AVCodecTag codec_bmp_tags[] = {
   { CODEC_ID_MPEG4,        MKTAG('X', 'V', 'I', 'D') },
   { CODEC_ID_MPEG4,        MKTAG('M', 'P', '4', 'S') },
   { CODEC_ID_MPEG4,        MKTAG('M', '4', 'S', '2') },
-  { CODEC_ID_MPEG4,        MKTAG( 4 ,  0 ,  0 ,  0 ) }, /* some broken avi use this */
+  { CODEC_ID_MPEG4,        MKTAG(4 ,  0 ,  0 ,  0) },   /* some broken avi use this */
   { CODEC_ID_MPEG4,        MKTAG('D', 'I', 'V', '1') },
   { CODEC_ID_MPEG4,        MKTAG('B', 'L', 'Z', '0') },
   { CODEC_ID_MPEG4,        MKTAG('m', 'p', '4', 'v') },
@@ -157,9 +464,9 @@ const AVCodecTag codec_bmp_tags[] = {
   { CODEC_ID_MPEG1VIDEO,   MKTAG('P', 'I', 'M', '1') },
   { CODEC_ID_MPEG2VIDEO,   MKTAG('P', 'I', 'M', '2') },
   { CODEC_ID_MPEG1VIDEO,   MKTAG('V', 'C', 'R', '2') },
-  { CODEC_ID_MPEG1VIDEO,   MKTAG( 1 ,  0 ,  0 ,  16) },
-  { CODEC_ID_MPEG2VIDEO,   MKTAG( 2 ,  0 ,  0 ,  16) },
-  { CODEC_ID_MPEG4,        MKTAG( 4 ,  0 ,  0 ,  16) },
+  { CODEC_ID_MPEG1VIDEO,   MKTAG(1 ,  0 ,  0 ,  16) },
+  { CODEC_ID_MPEG2VIDEO,   MKTAG(2 ,  0 ,  0 ,  16) },
+  { CODEC_ID_MPEG4,        MKTAG(4 ,  0 ,  0 ,  16) },
   { CODEC_ID_MPEG2VIDEO,   MKTAG('D', 'V', 'R', ' ') },
   { CODEC_ID_MPEG2VIDEO,   MKTAG('M', 'M', 'E', 'S') },
   { CODEC_ID_MPEG2VIDEO,   MKTAG('L', 'M', 'P', '2') }, /* Lead MPEG2 in avi */
@@ -189,8 +496,8 @@ const AVCodecTag codec_bmp_tags[] = {
   { CODEC_ID_HUFFYUV,      MKTAG('H', 'F', 'Y', 'U') },
   { CODEC_ID_FFVHUFF,      MKTAG('F', 'F', 'V', 'H') },
   { CODEC_ID_CYUV,         MKTAG('C', 'Y', 'U', 'V') },
-  { CODEC_ID_RAWVIDEO,     MKTAG( 0 ,  0 ,  0 ,  0 ) },
-  { CODEC_ID_RAWVIDEO,     MKTAG( 3 ,  0 ,  0 ,  0 ) },
+  { CODEC_ID_RAWVIDEO,     MKTAG(0 ,  0 ,  0 ,  0) },
+  { CODEC_ID_RAWVIDEO,     MKTAG(3 ,  0 ,  0 ,  0) },
   { CODEC_ID_RAWVIDEO,     MKTAG('I', '4', '2', '0') },
   { CODEC_ID_RAWVIDEO,     MKTAG('Y', 'U', 'Y', '2') },
   { CODEC_ID_RAWVIDEO,     MKTAG('Y', '4', '2', '2') },
@@ -210,9 +517,6 @@ const AVCodecTag codec_bmp_tags[] = {
   { CODEC_ID_RAWVIDEO,     MKTAG('H', 'D', 'Y', 'C') },
   { CODEC_ID_RAWVIDEO,     MKTAG('Y', 'V', 'U', '9') },
   { CODEC_ID_RAWVIDEO,     MKTAG('V', 'D', 'T', 'Z') }, /* SoftLab-NSK VideoTizer */
-  { CODEC_ID_FRWU,         MKTAG('F', 'R', 'W', 'U') },
-  { CODEC_ID_R210,         MKTAG('r', '2', '1', '0') },
-  { CODEC_ID_V210,         MKTAG('v', '2', '1', '0') },
   { CODEC_ID_INDEO3,       MKTAG('I', 'V', '3', '1') },
   { CODEC_ID_INDEO3,       MKTAG('I', 'V', '3', '2') },
   { CODEC_ID_INDEO4,       MKTAG('I', 'V', '4', '1') },
@@ -232,8 +536,8 @@ const AVCodecTag codec_bmp_tags[] = {
   { CODEC_ID_XAN_WC4,      MKTAG('X', 'x', 'a', 'n') },
   { CODEC_ID_MIMIC,        MKTAG('L', 'M', '2', '0') },
   { CODEC_ID_MSRLE,        MKTAG('m', 'r', 'l', 'e') },
-  { CODEC_ID_MSRLE,        MKTAG( 1 ,  0 ,  0 ,  0 ) },
-  { CODEC_ID_MSRLE,        MKTAG( 2 ,  0 ,  0 ,  0 ) },
+  { CODEC_ID_MSRLE,        MKTAG(1 ,  0 ,  0 ,  0) },
+  { CODEC_ID_MSRLE,        MKTAG(2 ,  0 ,  0 ,  0) },
   { CODEC_ID_MSVIDEO1,     MKTAG('M', 'S', 'V', 'C') },
   { CODEC_ID_MSVIDEO1,     MKTAG('m', 's', 'v', 'c') },
   { CODEC_ID_MSVIDEO1,     MKTAG('C', 'R', 'A', 'M') },
@@ -245,7 +549,9 @@ const AVCodecTag codec_bmp_tags[] = {
   { CODEC_ID_TRUEMOTION1,  MKTAG('P', 'V', 'E', 'Z') },
   { CODEC_ID_MSZH,         MKTAG('M', 'S', 'Z', 'H') },
   { CODEC_ID_ZLIB,         MKTAG('Z', 'L', 'I', 'B') },
+#if FF_API_SNOW
   { CODEC_ID_SNOW,         MKTAG('S', 'N', 'O', 'W') },
+#endif
   { CODEC_ID_4XM,          MKTAG('4', 'X', 'M', 'V') },
   { CODEC_ID_FLV1,         MKTAG('F', 'L', 'V', '1') },
   { CODEC_ID_FLASHSV,      MKTAG('F', 'S', 'V', '1') },
@@ -281,10 +587,6 @@ const AVCodecTag codec_bmp_tags[] = {
   { CODEC_ID_RPZA,         MKTAG('R', 'P', 'Z', 'A') },
   { CODEC_ID_RPZA,         MKTAG('r', 'p', 'z', 'a') },
   { CODEC_ID_SP5X,         MKTAG('S', 'P', '5', '4') },
-  { CODEC_ID_AURA,         MKTAG('A', 'U', 'R', 'A') },
-  { CODEC_ID_AURA2,        MKTAG('A', 'U', 'R', '2') },
-  { CODEC_ID_DPX,          MKTAG('d', 'p', 'x', ' ') },
-  { CODEC_ID_KGV1,         MKTAG('K', 'G', 'V', '1') },
   { CODEC_ID_NONE,         0 }
 };
 
@@ -320,7 +622,6 @@ int avi_pix_fmt_to_weed_palette(enum PixelFormat pix_fmt, int *clamped) {
   case PIX_FMT_UYYVYY411:
     return WEED_PALETTE_YUV411;
   case PIX_FMT_GRAY8:
-  case PIX_FMT_Y400A:
     return WEED_PALETTE_A8;
   case PIX_FMT_MONOWHITE:
   case PIX_FMT_MONOBLACK:
@@ -347,7 +648,7 @@ enum PixelFormat weed_palette_to_avi_pix_fmt(int pal, int *clamped) {
 
   switch (pal) {
   case WEED_PALETTE_RGB24:
-    return PIX_FMT_RGB24;
+      return PIX_FMT_RGB24;
   case WEED_PALETTE_BGR24:
     return PIX_FMT_BGR24;
   case WEED_PALETTE_RGBA32:
@@ -388,7 +689,8 @@ enum PixelFormat weed_palette_to_avi_pix_fmt(int pal, int *clamped) {
 
 }
 
-#endif
+#endif // HAVE_AVUTIL
+#endif // HAVE_AVCODEC
 
 #ifdef __cplusplus
 }
