@@ -17,12 +17,12 @@ extern "C"
 
 // palettes, etc.
 #ifdef HAVE_SYSTEM_WEED
-#include "weed/weed-palettes.h"
+#include <weed/weed-palettes.h>
 #else
 #include "../../../libweed/weed-palettes.h"
 #endif
 
-#ifdef IS_DARWIN
+#if defined (IS_DARWIN) || defined (__FreeBSD__)
 #ifndef lseek64
 #define lseek64 lseek
 #endif
@@ -32,7 +32,7 @@ extern "C"
 #endif
 
 
-  typedef int boolean;
+typedef int boolean;
 #undef TRUE
 #undef FALSE
 #define TRUE 1
@@ -44,10 +44,10 @@ typedef enum {
   LIVES_INTERLACE_TOP_FIRST=2
 } lives_interlace_t;
 
-  /// good
+/// good
 #define LIVES_SEEK_FAST (1<<0)
 
-  /// not so good
+/// not so good
 #define LIVES_SEEK_NEEDS_CALCULATION (1<<1)
 #define LIVES_SEEK_QUALITY_LOSS (1<<2)
 
@@ -58,6 +58,10 @@ typedef struct {
   int nclips; ///< number of clips (titles) in container
   char container_name[512]; ///< name of container, e.g. "ogg" or NULL
 
+  char title[256];
+  char author[256];
+  char comment[256];
+
   /// plugin should init this to 0 if URI changes
   int current_clip; ///< current clip number in container (starts at 0, MUST be <= nclips) [rw host]
 
@@ -76,14 +80,15 @@ typedef struct {
 
   float par; ///< pixel aspect ratio (sample width / sample height)
 
+  float video_start_time;
 
   float fps;
 
-  int *palettes; ///< list of palettes which the format supports, terminated with WEED_PALETTE_END 
+  int *palettes; ///< list of palettes which the format supports, terminated with WEED_PALETTE_END
 
   /// plugin should init this to palettes[0] if URI changes
   int current_palette;  ///< current palette [rw host]; must be contained in palettes
-  
+
   int YUV_sampling;
   int YUV_clamping;
   int YUV_subspace;
@@ -99,6 +104,17 @@ typedef struct {
 
   int seek_flag; ///< bitmap of seek properties
 
+#define SYNC_HINT_AUDIO_TRIM_START (1<<0)
+#define SYNC_HINT_AUDIO_PAD_START (1<<1)
+#define SYNC_HINT_AUDIO_TRIM_END (1<<2)
+#define SYNC_HINT_AUDIO_PAD_END (1<<3)
+
+#define SYNC_HINT_VIDEO_PAD_START (1<<4)
+#define SYNC_HINT_VIDEO_PAD_END (1<<5)
+
+  int sync_hint;
+
+
   void *priv; ///< private data for demuxer/decoder
 
 } lives_clip_data_t;
@@ -109,17 +125,17 @@ typedef struct {
 const char *version(void);
 
 
-/// pass in NULL clip_data for the first call, subsequent calls (if the URI, current_clip or current_palette changes) 
+/// pass in NULL clip_data for the first call, subsequent calls (if the URI, current_clip or current_palette changes)
 /// should reuse the previous value. If URI or current_clip are invalid, clip_data will be freed and NULL returned.
 ///
 /// plugin may or may not check current_palette to see if it is valid
 
 // should be threadsafe, and clip_data should be freed with clip_data_free() when no longer required
 
-lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *clip_data);
+lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *);
 
 /// frame starts at 0
-  boolean get_frame(const lives_clip_data_t *cdata, int64_t frame, int *rowstrides, int height, void **pixel_data);
+boolean get_frame(const lives_clip_data_t *, int64_t frame, int *rowstrides, int height, void **pixel_data);
 
 /// free clip data - this should be called for each instance before unloading the module
 void clip_data_free(lives_clip_data_t *);
@@ -130,7 +146,10 @@ void clip_data_free(lives_clip_data_t *);
 // opt fns
 const char *module_check_init(void);
 
-int64_t rip_audio (const lives_clip_data_t *, const char *fname, int64_t stframe, int64_t nframes, unsigned char **abuff);
+boolean set_palette(lives_clip_data_t *);
+
+int64_t rip_audio(const lives_clip_data_t *, const char *fname, int64_t stframe, int64_t nframes, unsigned char **abuff);
+boolean rip_audio_sequential(const lives_clip_data_t *, const char *fname);
 void rip_audio_cleanup(const lives_clip_data_t *);
 
 void module_unload(void);
@@ -148,6 +167,8 @@ void module_unload(void);
 #define ABS(a) ((a)>=0.?(a):-(a))
 
 
+double get_fps(const char *uri);
+
 enum LiVESMediaType {
   LIVES_MEDIA_TYPE_UNKNOWN=0,
   LIVES_MEDIA_TYPE_VIDEO,
