@@ -16,34 +16,33 @@
 // see file COPYING or www.gnu.org for details
 
 #ifdef HAVE_SYSTEM_WEED
-#include "weed/weed.h"
-#include "weed/weed-palettes.h"
-#include "weed/weed-effects.h"
-#include "weed/weed-plugin.h"
+#include <weed/weed.h>
+#include <weed/weed-palettes.h>
+#include <weed/weed-effects.h>
 #else
 #include "../../libweed/weed.h"
 #include "../../libweed/weed-palettes.h"
 #include "../../libweed/weed-effects.h"
-#include "../../libweed/weed-plugin.h"
 #endif
 
 ///////////////////////////////////////////////////////////////////
 
 static int num_versions=2; // number of different weed api versions supported
-static int api_versions[]={131,100}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
+static int api_versions[]= {131,100}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
 
 static int package_version=1; // version of this package
 
 //////////////////////////////////////////////////////////////////
 
-#ifdef HAVE_SYSTEM_WEED
-#include "weed/weed-utils.h" // optional
-#include "weed/weed-plugin-utils.h" // optional
+#ifdef HAVE_SYSTEM_WEED_PLUGIN_H
+#include <weed/weed-plugin.h> // optional
 #else
-#include "../../libweed/weed-utils.h" // optional
-#include "../../libweed/weed-plugin-utils.h" // optional
+#include "../../libweed/weed-plugin.h" // optional
 #endif
 
+#include "weed-utils-code.c" // optional
+#include "weed-plugin-utils.c" // optional
+
 /////////////////////////////////////////////////////////////
 
 #include <strings.h>
@@ -65,29 +64,33 @@ struct _sdata {
 
 
 /* Background image is refreshed every frame */
-static void image_bgsubtract_update_y(RGB32 *src, int width, int height, struct _sdata *sdata) {
-  register int i;
+static void image_bgsubtract_update_y(RGB32 *src, int width, int height, int rowstride, struct _sdata *sdata) {
+  register int i,j;
   int R, G, B;
   RGB32 *p;
   short *q;
   unsigned char *r;
   int v;
-  int video_area=width*height;
-  
+
+  rowstride-=width;
+
   p = src;
   q = sdata->background;
   r = sdata->diff;
-  for(i=0; i<video_area; i++) {
-    R = ((*p)&0xff0000)>>(16-1);
-    G = ((*p)&0xff00)>>(8-2);
-    B = (*p)&0xff;
-    v = (R + G + B) - (int)(*q);
-    *q = (short)(R + G + B);
-    *r = ((v + sdata->threshold)>>24) | ((sdata->threshold - v)>>24);
-    
-    p++;
-    q++;
-    r++;
+  for (i=0; i<height; i++) {
+    for (j=0; j<width; j++) {
+      R = ((*p)&0xff0000)>>(16-1);
+      G = ((*p)&0xff00)>>(8-2);
+      B = (*p)&0xff;
+      v = (R + G + B) - (int)(*q);
+      *q = (short)(R + G + B);
+      *r = ((v + sdata->threshold)>>24) | ((sdata->threshold - v)>>24);
+
+      p++;
+      q++;
+      r++;
+    }
+    p+=rowstride;
   }
 }
 
@@ -98,14 +101,14 @@ void image_diff_filter(struct _sdata *sdata, int width, int height) {
   unsigned char *src, *dest;
   unsigned int count;
   unsigned int sum1, sum2, sum3;
-  
+
   src = sdata->diff;
   dest = sdata->diff2 + width +1;
-  for(y=1; y<height-1; y++) {
+  for (y=1; y<height-1; y++) {
     sum1 = src[0] + src[width] + src[width*2];
     sum2 = src[1] + src[width+1] + src[width*2+1];
     src += 2;
-    for(x=1; x<width-1; x++) {
+    for (x=1; x<width-1; x++) {
       sum3 = src[0] + src[width] + src[width*2];
       count = sum1 + sum2 + sum3;
       sum1 = sum2;
@@ -117,21 +120,20 @@ void image_diff_filter(struct _sdata *sdata, int width, int height) {
   }
 }
 
-static void clear_field(struct _sdata *sdata, int video_area)
-{
+static void clear_field(struct _sdata *sdata, int video_area) {
   bzero(sdata->field1, video_area);
 }
 
 /////////////////////////////////////////////////////////////
 
-int lifetv_init (weed_plant_t *inst) {
+int lifetv_init(weed_plant_t *inst) {
   struct _sdata *sdata;
   int height,width,video_area;
   weed_plant_t *in_channel;
   int error;
 
   sdata=weed_malloc(sizeof(struct _sdata));
-  if(sdata == NULL ) return WEED_ERROR_MEMORY_ALLOCATION;
+  if (sdata == NULL) return WEED_ERROR_MEMORY_ALLOCATION;
 
   in_channel=weed_get_plantptr_value(inst,"in_channels",&error);
 
@@ -148,7 +150,7 @@ int lifetv_init (weed_plant_t *inst) {
 
   sdata->diff = (unsigned char *)weed_malloc(video_area*sizeof(unsigned char));
 
-  if(sdata->diff == NULL ) {
+  if (sdata->diff == NULL) {
     weed_free(sdata->field);
     weed_free(sdata);
     return WEED_ERROR_MEMORY_ALLOCATION;
@@ -156,7 +158,7 @@ int lifetv_init (weed_plant_t *inst) {
 
   sdata->diff2 = (unsigned char *)weed_malloc(video_area*sizeof(unsigned char));
 
-  if(sdata->diff2 == NULL ) {
+  if (sdata->diff2 == NULL) {
     weed_free(sdata->diff);
     weed_free(sdata->field);
     weed_free(sdata);
@@ -165,7 +167,7 @@ int lifetv_init (weed_plant_t *inst) {
 
 
   sdata->background = (short *)weed_malloc(video_area*sizeof(short));
-  if(sdata->background == NULL ) {
+  if (sdata->background == NULL) {
     weed_free(sdata->field);
     weed_free(sdata->diff);
     weed_free(sdata->diff2);
@@ -173,7 +175,7 @@ int lifetv_init (weed_plant_t *inst) {
     return WEED_ERROR_MEMORY_ALLOCATION;
   }
 
-  if(sdata->background == NULL ) {
+  if (sdata->background == NULL) {
     weed_free(sdata->field);
     weed_free(sdata->diff);
     weed_free(sdata->diff2);
@@ -193,7 +195,7 @@ int lifetv_init (weed_plant_t *inst) {
 }
 
 
-int lifetv_deinit (weed_plant_t *inst) {
+int lifetv_deinit(weed_plant_t *inst) {
   struct _sdata *sdata;
   int error;
 
@@ -210,17 +212,22 @@ int lifetv_deinit (weed_plant_t *inst) {
 }
 
 
-int lifetv_process (weed_plant_t *inst, weed_timecode_t timestamp) {
-  int x, y;
+int lifetv_process(weed_plant_t *inst, weed_timecode_t timestamp) {
+  struct _sdata *sdata;
+
+  weed_plant_t *in_channel,*out_channel;
+
   unsigned char *p, *q, v;
   unsigned char sum, sum1, sum2, sum3;
-  RGB32 pix;
-  
+
   RGB32 *src,*dest;
-  struct _sdata *sdata;
-  int width,height,video_area;
+
+  RGB32 pix;
+
+  int width,height,video_area,irow,orow;
   int error;
-  weed_plant_t *in_channel,*out_channel;
+  register int x, y;
+
 
   sdata=weed_get_voidptr_value(inst,"plugin_internal",&error);
   in_channel=weed_get_plantptr_value(inst,"in_channels",&error);
@@ -232,13 +239,18 @@ int lifetv_process (weed_plant_t *inst, weed_timecode_t timestamp) {
   width = weed_get_int_value(in_channel,"width",&error);
   height = weed_get_int_value(in_channel,"height",&error);
 
+  irow = weed_get_int_value(in_channel,"rowstrides",&error)/4;
+  orow = weed_get_int_value(out_channel,"rowstrides",&error)/4-width;
+
   video_area=width*height;
 
-  image_bgsubtract_update_y(src,width,height,sdata);
+  image_bgsubtract_update_y(src,width,height,irow,sdata);
   image_diff_filter(sdata,width,height);
   p=sdata->diff2;
 
-  for(x=0; x<video_area; x++) {
+  irow-=width;
+
+  for (x=0; x<video_area; x++) {
     sdata->field1[x] |= p[x];
   }
 
@@ -248,10 +260,10 @@ int lifetv_process (weed_plant_t *inst, weed_timecode_t timestamp) {
   src += width + 1;
   /* each value of cell is 0 or 0xff. 0xff can be treated as -1, so
    * following equations treat each value as negative number. */
-  for(y=1; y<height-1; y++) {
+  for (y=1; y<height-1; y++) {
     sum1 = 0;
     sum2 = p[0] + p[width] + p[width*2];
-    for(x=1; x<width-1; x++) {
+    for (x=1; x<width-1; x++) {
       sum3 = p[1] + p[width+1] + p[width*2+1];
       sum = sum1 + sum2 + sum3;
       v = 0 - ((sum==0xfd)|((p[width]!=0)&(sum==0xfc)));
@@ -265,8 +277,8 @@ int lifetv_process (weed_plant_t *inst, weed_timecode_t timestamp) {
     }
     p += 2;
     q += 2;
-    src += 2;
-    dest += 2;
+    src += 2+irow;
+    dest += 2+orow;
   }
   p = sdata->field1;
   sdata->field1 = sdata->field2;
@@ -278,16 +290,17 @@ int lifetv_process (weed_plant_t *inst, weed_timecode_t timestamp) {
 
 
 
-weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
+weed_plant_t *weed_setup(weed_bootstrap_f weed_boot) {
   weed_plant_t *plugin_info=weed_plugin_info_init(weed_boot,num_versions,api_versions);
   if (plugin_info!=NULL) {
-    int palette_list[]={WEED_PALETTE_RGBA32,WEED_PALETTE_BGRA32,WEED_PALETTE_END};
+    int palette_list[]= {WEED_PALETTE_RGBA32,WEED_PALETTE_BGRA32,WEED_PALETTE_END};
 
-    weed_plant_t *in_chantmpls[]={weed_channel_template_init("in channel 0",WEED_CHANNEL_REINIT_ON_SIZE_CHANGE,palette_list),NULL};
-    weed_plant_t *out_chantmpls[]={weed_channel_template_init("out channel 0",0,palette_list),NULL};
-    weed_plant_t *filter_class=weed_filter_class_init("lifeTV","effectTV",1,0,&lifetv_init,&lifetv_process,&lifetv_deinit,in_chantmpls,out_chantmpls,NULL,NULL);
+    weed_plant_t *in_chantmpls[]= {weed_channel_template_init("in channel 0",WEED_CHANNEL_REINIT_ON_SIZE_CHANGE,palette_list),NULL};
+    weed_plant_t *out_chantmpls[]= {weed_channel_template_init("out channel 0",0,palette_list),NULL};
+    weed_plant_t *filter_class=weed_filter_class_init("lifeTV","effectTV",1,0,&lifetv_init,&lifetv_process,&lifetv_deinit,in_chantmpls,
+                               out_chantmpls,NULL,NULL);
 
-    weed_plugin_info_add_filter_class (plugin_info,filter_class);
+    weed_plugin_info_add_filter_class(plugin_info,filter_class);
 
     weed_set_int_value(plugin_info,"version",package_version);
   }
