@@ -19,34 +19,33 @@
 
 
 #ifdef HAVE_SYSTEM_WEED
-#include "weed/weed.h"
-#include "weed/weed-palettes.h"
-#include "weed/weed-effects.h"
-#include "weed/weed-plugin.h"
+#include <weed/weed.h>
+#include <weed/weed-palettes.h>
+#include <weed/weed-effects.h>
 #else
 #include "../../libweed/weed.h"
 #include "../../libweed/weed-palettes.h"
 #include "../../libweed/weed-effects.h"
-#include "../../libweed/weed-plugin.h"
 #endif
 
 ///////////////////////////////////////////////////////////////////
 
 static int num_versions=2; // number of different weed api versions supported
-static int api_versions[]={131,100}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
+static int api_versions[]= {131,100}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
 
 static int package_version=1; // version of this package
 
 //////////////////////////////////////////////////////////////////
 
-#ifdef HAVE_SYSTEM_WEED
-#include "weed/weed-utils.h" // optional
-#include "weed/weed-plugin-utils.h" // optional
+#ifdef HAVE_SYSTEM_WEED_PLUGIN_H
+#include <weed/weed-plugin.h> // optional
 #else
-#include "../../libweed/weed-utils.h" // optional
-#include "../../libweed/weed-plugin-utils.h" // optional
+#include "../../libweed/weed-plugin.h" // optional
 #endif
 
+#include "weed-utils-code.c" // optional
+#include "weed-plugin-utils.c" // optional
+
 /////////////////////////////////////////////////////////////
 
 #include <math.h>
@@ -64,7 +63,6 @@ typedef uint32_t Uint32;
 /////////////////////////////////
 
 struct _sdata {
-  int *offstable;
   Sint32 *disttable;
   Sint32 ctable[1024];
   Sint32 sintable[1024+256];
@@ -72,66 +70,59 @@ struct _sdata {
 };
 
 
-static void initSinTable (struct _sdata *sdata) {
+static void initSinTable(struct _sdata *sdata) {
   Sint32 *tptr, *tsinptr;
   double i;
 
   tsinptr = tptr = sdata->sintable;
-  
+
   for (i = 0; i < 1024; i++)
-    *tptr++ = (int) (sin (i*M_PI/512) * 32767);
-  
+    *tptr++ = (int)(sin(i*M_PI/512) * 32767);
+
   for (i = 0; i < 256; i++)
     *tptr++ = *tsinptr++;
 }
 
 
-static void initOffsTable (struct _sdata *sdata, int width, int height) {
-  int y;
-	
-  for (y = 0; y < height; y++) {
-    sdata->offstable[y] = y * width;
-  }
-}
 
 
-static void initDistTable (struct _sdata *sdata, int width, int height) {
+static void initDistTable(struct _sdata *sdata, int width, int height) {
   Sint32 halfw, halfh, *distptr;
 #ifdef PS2
   float	x,y,m;
 #else
-double x,y,m;
+  double x,y,m;
 #endif
 
-  halfw = width>> 1;
-  halfh = height >> 1;
-  
+  halfw = width/2.+.5;
+  halfh = height/2.+.5;
+
   distptr = sdata->disttable;
-  
-  m = sqrt ((double)(halfw*halfw + halfh*halfh));
-  
-for (y = -halfh; y < halfh; y++)
-     for (x= -halfw; x < halfw; x++)
+
+  m = sqrt((double)(halfw*halfw + halfh*halfh));
+
+  for (y = -halfh; y < halfh; y++)
+    for (x= -halfw; x < halfw; x++)
 #ifdef PS2
-     *distptr++ = ((int)
-     ( (sqrtf (x*x+y*y) * 511.100100) / m)) << 1;
+      *distptr++ = ((int)
+                    ((sqrtf(x*x+y*y) * 511.100100) / m)) << 1;
 #else
-  *distptr++ = ((int)
-     ( (sqrt (x*x+y*y) * 511.100100) / m)) << 1;
+      *distptr++ = ((int)
+                    ((sqrt(x*x+y*y) * 511.100100) / m)) << 1;
 #endif
 }
 
 
-static void doWarp (int xw, int yw, int cw,RGB32 *src,RGB32 *dst, int width, int height, struct _sdata *sdata) {
+static void doWarp(int xw, int yw, int cw,RGB32 *src,RGB32 *dst, int width, int height, int irow, int orow, struct _sdata *sdata) {
   Sint32 c,i, x,y, dx,dy, maxx, maxy;
   Sint32 skip, *ctptr, *distptr;
   Uint32 *destptr;
   //	Uint32 **offsptr;
-  
+
   ctptr = sdata->ctable;
   distptr = sdata->disttable;
   destptr = dst;
-  skip = 0 ; /* video_width*sizeof(RGB32)/4 - video_width;; */
+  skip = orow-width;
   c = 0;
   for (x = 0; x < 512; x++) {
     i = (c >> 3) & 0x3FE;
@@ -139,32 +130,34 @@ static void doWarp (int xw, int yw, int cw,RGB32 *src,RGB32 *dst, int width, int
     *ctptr++ = ((sdata->sintable[i+256] * xw) >> 15);
     c += cw;
   }
-  maxx = width - 2; maxy = height - 2;
+  maxx = width - 2;
+  maxy = height - 2;
   /*	printf("Forring\n"); */
   for (y = 0; y < height-1; y++) {
     for (x = 0; x < width; x++) {
-      i = *distptr++; 
-      dx = sdata->ctable [i+1] + x; 
-      dy = sdata->ctable [i] + y;	 
-      
-      
-      if (dx < 0) dx = 0; 
-      else if (dx > maxx) dx = maxx; 
-      
-      if (dy < 0) dy = 0; 
-      else if (dy > maxy) dy = maxy; 
+      i = *distptr;
+      distptr++;
+      dx = sdata->ctable [i+1] + x;
+      dy = sdata->ctable [i] + y;
+
+
+      if (dx < 0) dx = 0;
+      else if (dx > maxx) dx = maxx;
+
+      if (dy < 0) dy = 0;
+      else if (dy > maxy) dy = maxy;
       /* 	   printf("f:%d\n",dy); */
       /*	   printf("%d\t%d\n",dx,dy); */
-      *destptr++ = src[sdata->offstable[dy]+dx]; 
+      *destptr++ = src[dy*irow+dx];
     }
     destptr += skip;
   }
-  
+
 }
 
 /////////////////////////////////////////////////////////////
 
-int warp_init (weed_plant_t *inst) {
+int warp_init(weed_plant_t *inst) {
   int video_height;
   int video_width;
   int error;
@@ -180,21 +173,20 @@ int warp_init (weed_plant_t *inst) {
   video_height=weed_get_int_value(in_channel,"height",&error);
   video_width=weed_get_int_value(in_channel,"width",&error);
 
-  sdata->offstable = (int *)weed_malloc (video_height * sizeof (int));      
-  if(sdata->offstable == NULL ) {
-    weed_free(sdata);
-    return WEED_ERROR_MEMORY_ALLOCATION;
-  }
-  sdata->disttable = weed_malloc (video_width * video_height * sizeof (int));
-  if(sdata->disttable == NULL ) {
-    weed_free(sdata->offstable);
+  video_width=video_width/2.+.5;
+  video_width*=2;
+
+  video_height=video_height/2.+.5;
+  video_height*=2;
+
+  sdata->disttable = weed_malloc(video_width * video_height * sizeof(int));
+  if (sdata->disttable == NULL) {
     weed_free(sdata);
     return WEED_ERROR_MEMORY_ALLOCATION;
   }
 
-  initSinTable (sdata);
-  initOffsTable (sdata,video_width,video_height);
-  initDistTable (sdata,video_width,video_height);
+  initSinTable(sdata);
+  initDistTable(sdata,video_width,video_height);
 
   sdata->tval=0;
 
@@ -204,12 +196,11 @@ int warp_init (weed_plant_t *inst) {
 }
 
 
-int warp_deinit (weed_plant_t *inst) {
+int warp_deinit(weed_plant_t *inst) {
   int error;
   struct _sdata *sdata;
   sdata=weed_get_voidptr_value(inst,"plugin_internal",&error);
   if (sdata != NULL) {
-    weed_free(sdata->offstable);
     weed_free(sdata->disttable);
     weed_free(sdata);
     weed_set_voidptr_value(inst,"plugin_internal",NULL);
@@ -218,13 +209,14 @@ int warp_deinit (weed_plant_t *inst) {
 }
 
 
-int warp_process (weed_plant_t *inst, weed_timecode_t timestamp) {
+int warp_process(weed_plant_t *inst, weed_timecode_t timestamp) {
+  RGB32 *src,*dest;
+  struct _sdata *sdata;
+
   int error;
   int xw,yw,cw;
 
-  RGB32 *src,*dest;
-  struct _sdata *sdata;
-  int width,height;
+  int width,height,irow,orow;
 
   weed_plant_t *in_channel,*out_channel;
 
@@ -238,13 +230,17 @@ int warp_process (weed_plant_t *inst, weed_timecode_t timestamp) {
   width = weed_get_int_value(in_channel,"width",&error);
   height = weed_get_int_value(in_channel,"height",&error);
 
-  xw  = (int) (sin((sdata->tval+100)*M_PI/128) * 30);
-  yw  = (int) (sin((sdata->tval)*M_PI/256) * -35);
-  cw  = (int) (sin((sdata->tval-70)*M_PI/64) * 50);
-  xw += (int) (sin((sdata->tval-10)*M_PI/512) * 40);
-  yw += (int) (sin((sdata->tval+30)*M_PI/512) * 40);	  
+  irow = weed_get_int_value(in_channel,"rowstrides",&error)/4;
+  orow = weed_get_int_value(out_channel,"rowstrides",&error)/4;
 
-  doWarp(xw,yw,cw,src,dest,width,height,sdata);
+
+  xw  = (int)(sin((sdata->tval+100)*M_PI/128) * 30);
+  yw  = (int)(sin((sdata->tval)*M_PI/256) * -35);
+  cw  = (int)(sin((sdata->tval-70)*M_PI/64) * 50);
+  xw += (int)(sin((sdata->tval-10)*M_PI/512) * 40);
+  yw += (int)(sin((sdata->tval+30)*M_PI/512) * 40);
+
+  doWarp(xw,yw,cw,src,dest,width,height,irow,orow,sdata);
   sdata->tval = (sdata->tval+1) &511;
 
   return WEED_NO_ERROR;
@@ -253,18 +249,19 @@ int warp_process (weed_plant_t *inst, weed_timecode_t timestamp) {
 
 
 
-weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
+weed_plant_t *weed_setup(weed_bootstrap_f weed_boot) {
   weed_plant_t *plugin_info=weed_plugin_info_init(weed_boot,num_versions,api_versions);
 
   if (plugin_info!=NULL) {
-    int palette_list[]={WEED_PALETTE_RGBA32,WEED_PALETTE_END};
-    weed_plant_t *in_chantmpls[]={weed_channel_template_init("in channel 0",WEED_CHANNEL_REINIT_ON_SIZE_CHANGE,palette_list),NULL};
-    weed_plant_t *out_chantmpls[]={weed_channel_template_init("out channel 0",0,palette_list),NULL};
-    
-    weed_plant_t *filter_class=weed_filter_class_init("warpTV","effectTV",1,0,&warp_init,&warp_process,&warp_deinit,in_chantmpls,out_chantmpls,NULL,NULL);
-    
-    weed_plugin_info_add_filter_class (plugin_info,filter_class);
-    
+    int palette_list[]= {WEED_PALETTE_RGBA32,WEED_PALETTE_END};
+    weed_plant_t *in_chantmpls[]= {weed_channel_template_init("in channel 0",WEED_CHANNEL_REINIT_ON_SIZE_CHANGE,palette_list),NULL};
+    weed_plant_t *out_chantmpls[]= {weed_channel_template_init("out channel 0",0,palette_list),NULL};
+
+    weed_plant_t *filter_class=weed_filter_class_init("warpTV","effectTV",1,0,&warp_init,&warp_process,&warp_deinit,in_chantmpls,out_chantmpls,
+                               NULL,NULL);
+
+    weed_plugin_info_add_filter_class(plugin_info,filter_class);
+
     weed_set_int_value(plugin_info,"version",package_version);
   }
 
