@@ -5,6 +5,8 @@
 // released under the GNU GPL 3 or later
 // see file COPYING or www.gnu.org for details
 
+// (c) G. Finch 2002 - 2015
+
 #ifndef LIVES_PANGOTEXT_H
 #define LIVES_PANGOTEXT_H
 
@@ -22,15 +24,15 @@ typedef struct {
 } lives_subtitle_style_t;
 
 
-typedef struct lives_subtitle_t _lives_subtitle_t;
+typedef struct _lives_subtitle_t xlives_subtitle_t;
 
-typedef struct {
+typedef struct _lives_subtitle_t {
   double start_time;
   double end_time;
   lives_subtitle_style_t *style; ///< for future use
   long textpos;
-  _lives_subtitle_t *prev; ///< for future use
-  _lives_subtitle_t *next;
+  xlives_subtitle_t *prev; ///< for future use
+  xlives_subtitle_t *next;
 } lives_subtitle_t;
 
 
@@ -54,9 +56,13 @@ typedef enum {
 
 char **get_font_list(void);
 
-gboolean render_text_to_layer(weed_plant_t *layer, const char *text, const char *fontname,\
-  double size, lives_text_mode_t mode, lives_colRGBA32_t *fg_col, lives_colRGBA32_t *bg_col,\
-  gboolean center, gboolean rising, double top);
+weed_plant_t *render_text_to_layer(weed_plant_t *layer, const char *text, const char *fontname,
+                                   double size, lives_text_mode_t mode, lives_colRGBA32_t *fg_col,
+                                   lives_colRGBA32_t *bg_col, boolean center, boolean rising, double top);
+
+LingoLayout *render_text_to_cr(lives_painter_t *, const char *text, const char *fontname,
+                               double size, lives_text_mode_t mode, lives_colRGBA32_t *fg_col, lives_colRGBA32_t *bg_col,
+                               boolean center, boolean rising, double top, int start, int width, int height);
 
 #endif
 
