@@ -1,6 +1,6 @@
 // pulse.h
 // LiVES (lives-exe)
-// (c) G. Finch 2005 - 2009
+// (c) G. Finch 2005 - 2012
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -13,16 +13,15 @@
 #include <pulse/proplist.h>
 #include <pulse/error.h>
 
-#include "audio.h"
-
-
 #define PULSE_MAX_OUTPUT_CHANS PA_CHANNEL_POSITION_MAX
 
 #define LIVES_PA_BUFF_MAXLEN 16384
-#define LIVES_PA_BUFF_TARGET 4096
+#define LIVES_PA_BUFF_TARGET 1024
+#define LIVES_PA_BUFF_FRAGSIZE 1024
 
 typedef struct {
   size_t size;
+  size_t max_size;
   void *data;
 } audio_buffer_t;
 
@@ -33,21 +32,23 @@ typedef struct {
   pa_stream *pstream;
   pa_proplist *pa_props;
 
+  pa_usec_t usec_start;
+
   int str_idx;
 
   pa_context_state_t state;
 
   // app side
-  glong in_arate; /**< samples(frames) per second */
-  gulong in_achans; /**< number of input channels(1 is mono, 2 stereo etc..) */
-  gulong in_asamps;
+  int64_t in_arate; /**< samples(frames) per second */
+  uint64_t in_achans; /**< number of input channels(1 is mono, 2 stereo etc..) */
+  uint64_t in_asamps;
 
   // server side
-  glong out_arate; /**< samples(frames) per second */
-  gulong out_achans; /**< number of output channels(1 is mono, 2 stereo etc..) */
-  gulong out_asamps;
+  int64_t out_arate; /**< samples(frames) per second */
+  uint64_t out_achans; /**< number of output channels(1 is mono, 2 stereo etc..) */
+  uint64_t out_asamps;
 
-  gulong out_chans_available;
+  uint64_t out_chans_available;
 
   int in_signed;
   int in_endian;
@@ -55,49 +56,49 @@ typedef struct {
   int out_signed;
   int out_endian;
 
-  gulong num_calls; /**< count of process_audio() calls */
+  uint64_t num_calls; /**< count of process_audio() calls */
 
-  audio_buffer_t* aPlayPtr; ///< data read from file
+  audio_buffer_t *aPlayPtr; ///< data read from file
   lives_audio_loop_t loop;
 
-  guchar* sound_buffer; ///< transformed data
+  uint8_t *sound_buffer; ///< transformed data
 
   float volume[PULSE_MAX_OUTPUT_CHANS]; ///< amount volume, 1.0 is full volume
 
-  gboolean in_use; /**< true if this device is currently in use */
-  gboolean mute;
+  boolean in_use; /**< true if this device is currently in use */
+  boolean mute;
 
   /**< linked list of messages we are sending to the callback process */
   volatile aserver_message_t   *msgq;
 
-  gulong frames_written;
+  volatile uint64_t frames_written;
 
-  gboolean is_paused;
+  boolean is_paused;
 
-  gint64 audio_ticks; ///< ticks when we did the last seek, used to calculate current ticks from audio
+  volatile int64_t audio_ticks; ///< ticks when we did the last seek, used to calculate current ticks from audio
 
-  int fd; /**< if >0 we are playing from a file */
-  gboolean is_opening; ///< TRUE if file is opening (audiodump.pcm)
+  int fd; /**< if >0 we are playing from a lives_clip_t */
+  boolean is_opening; ///< TRUE if file is opening (audiodump.pcm)
   volatile off_t seek_pos;
   off_t seek_end;
-  gboolean usigned;
-  gboolean reverse_endian;
+  boolean usigned;
+  boolean reverse_endian;
 
   lives_whentostop_t *whentostop; ///< pointer to mainw->whentostop
   volatile lives_cancel_t *cancelled; ///< pointer to mainw->cancelled
 
   /* variables used for trying to restart the connection to pulse */
-  gboolean pulsed_died;
+  boolean pulsed_died;
   struct timeval last_reconnect_attempt;
 
-  gboolean is_output; ///< is output FROM host to jack
+  boolean is_output; ///< is output FROM host to jack
 
-  gint playing_file;
+  int playing_file;
 
   lives_audio_buf_t **abufs;
-  volatile gint read_abuf;
+  volatile int read_abuf;
 
-  gulong chunk_size;
+  uint64_t chunk_size;
 
   volatile int astream_fd;
 
@@ -107,35 +108,39 @@ typedef struct {
 
 // TODO - rationalise names
 
-gboolean lives_pulse_init (short startup_phase); ///< init server, mainloop and context
+boolean lives_pulse_init(short startup_phase);  ///< init server, mainloop and context
 
 int pulse_audio_init(void);  ///< init driver vars.
 int pulse_audio_read_init(void); // ditto
 
-pulse_driver_t *pulse_get_driver(gboolean is_output); ///< get driver refs
+pulse_driver_t *pulse_get_driver(boolean is_output); ///< get driver refs
 
 int pulse_driver_activate(pulse_driver_t *); ///< connect to server
 void pulse_close_client(pulse_driver_t *);
 
 void pulse_shutdown(void); ///< shudown server, mainloop, context
 
-void pulse_flush_read_data(pulse_driver_t *, size_t rbytes, void *data);
+void pulse_aud_pb_ready(int fileno);
+
+size_t pulse_flush_read_data(pulse_driver_t *, int fileno, size_t rbytes, boolean rev_endian, void *data);
 
 void pulse_driver_uncork(pulse_driver_t *);
 
+boolean pulse_try_reconnect(void);
+
 // utils
 volatile aserver_message_t *pulse_get_msgq(pulse_driver_t *); ///< pull last msg from msgq, or return NULL
 
-long pulse_audio_seek_bytes (pulse_driver_t *, long bytes); ///< seek to byte position
+int64_t pulse_audio_seek_bytes(pulse_driver_t *, int64_t bytes);  ///< seek to byte position
 
-gint64 lives_pulse_get_time(pulse_driver_t *, gboolean absolute); ///< get time from pa, in 10^-8 seconds
+int64_t lives_pulse_get_time(pulse_driver_t *, boolean absolute); ///< get time from pa, in 10^-8 seconds
 
-gdouble lives_pulse_get_pos(pulse_driver_t *);
+double lives_pulse_get_pos(pulse_driver_t *);
 
 
 //////////////////////
 
-void pulse_audio_seek_frame (pulse_driver_t *, gint frame); ///< seek to (video) frame
+boolean pulse_audio_seek_frame(pulse_driver_t *, int frame);  ///< seek to (video) frame
 
 void pulse_get_rec_avals(pulse_driver_t *);
 
